@@ -225,12 +225,17 @@ class Action():
                 update.message.reply_audio(audio, title=item["title"], performer=item["performer"], reply_markup=reply_markup)
 
             elif item["type"] == "voice":
+                if "caption" in item.keys():
+                    caption = item["caption"]
+                else:
+                    caption = None
+
                 if "file" in item.keys():
                     voice = open(item["file"], 'rb')
                 else:
                     voice = item["url"]
 
-                update.message.reply_audio(voice, caption=item["caption"], reply_markup=reply_markup)
+                update.message.reply_voice(voice, caption=caption, reply_markup=reply_markup)
 
 
             elif item["type"] == "contact":
