@@ -55,14 +55,15 @@ def readActions(format_inhalt_list, messanger="Telegram", asset_url=""):
 
             match = re.search(regex, inhalt)
             if match:
-                mp3_filename = os.path.join("assets/", match.group('file'))
-                ogg_filename = mp3_filename.replace(".mp3", ".ogg")
-                subprocess.run(["ffmpeg", '-i', mp3_filename, "-ac", "1", '-acodec', 'libopus', ogg_filename, '-y'])
+                mp3_filepath = os.path.join("assets/", match.group('file'))
+                ogg_filename = match.group('file').replace(".mp3", ".ogg")
+                ogg_filepath =  os.path.join("assets/", ogg_filename)
+                subprocess.run(["ffmpeg", '-i', mp3_filepath, "-ac", "1", '-acodec', 'libopus', ogg_filepath, '-y'])
 
                 if messanger=="Telegram":
-                    action["file"] = ogg_filename
+                    action["file"] = ogg_filepath
                 else:
-                    action["url"] = os.path.join(asset_url, ogg_filename)
+                    action["url"] = os.path.join(asset_url, match.group('file'))
                 action["caption"] = match.group('name')
             else:
                 action["url"] = os.path.join(asset_url, "platzhalter.mp3")
