@@ -1,17 +1,17 @@
 from collections import defaultdict
 from digitalguide.standardinteraktion.Interaktion import Interaktion
 
-
 class Route:
     def __init__(self):
         self.interaktionen = []
         self.states = defaultdict(list)
         self.actions = defaultdict(list)
 
-    def from_excel_dict(self, excel_dict, messanger="Telegram"):
+    def from_excel_dict(self, excel_dict, messanger="Telegram", asset_url=""):
+        self.messanger = messanger
         for excel_dict_item in excel_dict.items():
         
-            interaktion = Interaktion.from_excel_dict(excel_dict_item, messanger=messanger)
+            interaktion = Interaktion.from_excel_dict(excel_dict_item, messanger=messanger, asset_url=asset_url)
             
             self.interaktionen.append(interaktion)
 
@@ -34,7 +34,15 @@ class Route:
         for interaktion in self.interaktionen:
             self.states = {**self.states, **interaktion.states}
 
-        self.states["NONE"]=[]
+        if self.messanger == "Telegram":
+            self.states["NONE"]=[]
+        if self.messanger == "WhatsApp":
+            from configparser import ConfigParser
+
+            config = ConfigParser()
+            config.read("config.ini")
+
+            self.states["START_START"]=[{"handler": "TypeHandler", "type": "Update", "action": config["bot"]["start_action"]}]
 
     def generate_actions(self):
         self.actions = {}
